@@ -14,12 +14,10 @@ from openassessment.assessment.api.staff import _complete_assessment
 from openassessment.assessment.errors import StaffAssessmentInternalError, StaffAssessmentRequestError
 from openassessment.assessment.models import Assessment, TeamStaffWorkflow, InvalidRubricSelection
 from openassessment.assessment.serializers import InvalidRubric, full_assessment_dict
-
+from openassessment.assessment.score_type_constants import STAFF_TYPE
 
 logger = logging.getLogger(__name__)  # pylint: disable=invalid-name
 
-STAFF_TYPE = "ST"
-
 
 def submitter_is_finished(team_submission_uuid, team_requirements):  # pylint: disable=unused-argument
     """
