@@ -40,7 +40,7 @@ class Command(BaseCommand):
     def __init__(self, *args, **kwargs):
         self.self_assessment_required = kwargs.get('self_assessment_required', False)
         kwargs = {}
-        super(Command, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._student_items = list()
 
     def handle(self, *args, **options):
@@ -61,16 +61,16 @@ class Command(BaseCommand):
 
         try:
             num_submissions = int(args[2])
-        except ValueError:
-            raise CommandError('Number of submissions must be an integer')
+        except ValueError as ex:
+            raise CommandError('Number of submissions must be an integer') from ex
 
         try:
             percentage = float(args[3])
             assessments_to_create = (percentage / 100) * num_submissions
-        except ValueError:
-            raise CommandError('Percentage for completed submissions must be an integer or float')
+        except ValueError as ex:
+            raise CommandError('Percentage for completed submissions must be an integer or float') from ex
 
-        print(u"Creating {num} submissions for {item} in {course}".format(
+        print("Creating {num} submissions for {item} in {course}".format(
             num=num_submissions, item=item_id, course=course_id
         ))
 
@@ -78,7 +78,7 @@ class Command(BaseCommand):
 
         for sub_num in range(num_submissions):
 
-            print(u"Creating submission {num}".format(num=sub_num))
+            print(f"Creating submission {sub_num}")
 
             # Create a dummy submission
             student_item = {
@@ -95,9 +95,9 @@ class Command(BaseCommand):
 
             # Create peer assessments
             for num in range(self.NUM_PEER_ASSESSMENTS):
-                print(u"-- Creating peer-workflow {num}".format(num=num))
+                print(f"-- Creating peer-workflow {num}")
 
-                scorer_id = 'test_{num}'.format(num=num)
+                scorer_id = f'test_{num}'
 
                 # The scorer needs to make a submission before assessing
                 scorer_student_item = copy.copy(student_item)
@@ -109,7 +109,7 @@ class Command(BaseCommand):
                 # exactly which submission we want to score.
                 peer_api.create_peer_workflow_item(scorer_submission_uuid, submission_uuid)
                 if assessments_created < assessments_to_create:
-                    print(u"-- Creating peer-assessment {num}".format(num=num))
+                    print(f"-- Creating peer-assessment {num}")
                     # Create the peer assessment
                     peer_api.create_assessment(
                         scorer_submission_uuid,
@@ -122,12 +122,12 @@ class Command(BaseCommand):
 
             if self.self_assessment_required:
                 # Create a self-assessment
-                print(u"-- Creating self assessment")
+                print("-- Creating self assessment")
                 self_api.create_assessment(
                     submission_uuid, student_item['student_id'],
                     options_selected, {}, "  ".join(loremipsum.get_paragraphs(2)), rubric
                 )
-        print(u"%s assessments being completed for %s submissions" % (assessments_created, num_submissions))
+        print("%s assessments being completed for %s submissions" % (assessments_created, num_submissions))
 
     @property
     def student_items(self):
