@@ -20,13 +20,13 @@ the listener will ignore the notification.
 Args:
     listeners (array): List of objects
 
-**/
-OpenAssessment.Notifier = function(listeners) {
+* */
+export class Notifier {
+  constructor(listeners) {
     this.listeners = listeners;
-};
+  }
 
-OpenAssessment.Notifier.prototype = {
-    /**
+  /**
     Fire a notification, which will be received
 
     Args:
@@ -36,12 +36,14 @@ OpenAssessment.Notifier.prototype = {
 
         data (object literal): Arbitrary data to include with the notification.
 
-    **/
-    notificationFired: function(name, data) {
-        for (var i = 0; i < this.listeners.length; i++) {
-            if (typeof(this.listeners[i][name]) === 'function') {
-                this.listeners[i][name](data);
-            }
-        }
-    },
-};
+    * */
+  notificationFired(name, data) {
+    for (let i = 0; i < this.listeners.length; i++) {
+      if (typeof (this.listeners[i][name]) === 'function') {
+        this.listeners[i][name](data);
+      }
+    }
+  }
+}
+
+export default Notifier;
